#include "LPC11xx.h"

#include <stdbool.h>
#include <stdio.h>
#include <string.h>

#ifdef DEBUG
 #define PRINTF(...) printf(__VA_ARGS__)
#else
 #define PRINTF(...) ((void)0)
#endif

#include "I2CEEprom.h"

volatile uint32_t Timer1000;

#define PIN_MASK_LED1 (1U << 10)
#define PIN_MASK_LED2 (1U << 9)

#define LPC_GPIO_LED LPC_GPIO2


static inline void SetLed1(bool on)
{
	LPC_GPIO_LED->MASKED_ACCESS[PIN_MASK_LED1] = on ? 0 : PIN_MASK_LED1;	// low-aktiv
}

static inline void SetLed2(bool on)
{
	LPC_GPIO_LED->MASKED_ACCESS[PIN_MASK_LED2] = on ? 0 : PIN_MASK_LED2;	// low-aktiv
}


void SysTick_Handler(void)
{
	Timer1000++;
}

#define ReadTime() Timer1000

static inline uint32_t Elapsed(uint32_t since)
{
	return ReadTime() - since;
}

void Delay(uint32_t d)
{
	uint32_t start = ReadTime();
	while (Elapsed(start) < d)
	{
		__WFI();
	}
}

int main(void)
{
	SystemCoreClockUpdate();
	LPC_SYSCON->SYSAHBCLKDIV = 1;								// Prescaler of 1 for AHB
	PRINTF("Hello World; Clock is %u MHz\n", SystemCoreClock);

	// Enable and setup SysTick Timer at a 1000Hz
	SysTick_Config(SystemCoreClock / 1000);

	I2CEEpromInit();

	SetLed1(false);
	SetLed2(false);
	LPC_GPIO_LED->DIR |= PIN_MASK_LED1|PIN_MASK_LED2;

	char buff[8] = "ABCD1234";
	I2CEEPromWrite(0, buff, sizeof(buff));
	memset(buff, 0, sizeof(buff));
	I2CEEPromRead(0, buff, sizeof(buff));

    while(1)
    {
        Delay(100);
        SetLed1(1);
        Delay(100);
        SetLed2(1);
        Delay(700);
        SetLed1(0);
        Delay(100);
        SetLed2(0);
    }
}
